@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -55,9 +55,7 @@ class CmeClient(AbstractClient):
 
 
     def CreateClass(self, request):
-        """新增分类，用于管理素材。
-        <li>分类层数不能超过10；</li>
-        <li>子分类数不能超过10。</li>
+        """新增分类，用于管理素材。分类层数不能超过20。
 
         :param request: Request instance for CreateClass.
         :type request: :class:`tencentcloud.cme.v20191029.models.CreateClassRequest`
