@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -38,6 +40,13 @@ class AgeInfo(AbstractModel):
         if params.get("FaceRect") is not None:
             self.FaceRect = FaceRect()
             self.FaceRect._deserialize(params.get("FaceRect"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CancelFaceMorphJobRequest(AbstractModel):
@@ -55,6 +64,13 @@ class CancelFaceMorphJobRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.JobId = params.get("JobId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CancelFaceMorphJobResponse(AbstractModel):
@@ -112,6 +128,13 @@ class ChangeAgePicRequest(AbstractModel):
         self.Image = params.get("Image")
         self.Url = params.get("Url")
         self.RspImgType = params.get("RspImgType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ChangeAgePicResponse(AbstractModel):
@@ -171,6 +194,13 @@ class FaceCartoonPicRequest(AbstractModel):
         self.Url = params.get("Url")
         self.RspImgType = params.get("RspImgType")
         self.DisableGlobalEffect = params.get("DisableGlobalEffect")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class FaceCartoonPicResponse(AbstractModel):
@@ -224,6 +254,13 @@ class FaceMorphOutput(AbstractModel):
         self.MorphUrl = params.get("MorphUrl")
         self.MorphMd5 = params.get("MorphMd5")
         self.CoverImage = params.get("CoverImage")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class FaceRect(AbstractModel):
@@ -253,6 +290,13 @@ class FaceRect(AbstractModel):
         self.X = params.get("X")
         self.Width = params.get("Width")
         self.Height = params.get("Height")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GenderInfo(AbstractModel):
@@ -277,6 +321,13 @@ class GenderInfo(AbstractModel):
         if params.get("FaceRect") is not None:
             self.FaceRect = FaceRect()
             self.FaceRect._deserialize(params.get("FaceRect"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GradientInfo(AbstractModel):
@@ -298,6 +349,13 @@ class GradientInfo(AbstractModel):
     def _deserialize(self, params):
         self.Tempo = params.get("Tempo")
         self.MorphTime = params.get("MorphTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class MorphFaceRequest(AbstractModel):
@@ -324,7 +382,7 @@ Url、Image必须提供一个，如果都提供，只使用 Url。图片存储
         :type GradientInfos: list of GradientInfo
         :param Fps: 视频帧率，取值[1,25]。默认10
         :type Fps: int
-        :param OutputType: 视频类型，取值[0,2]，其中0为MP4，1为GIF，2为MOV。目前仅支持MP4格式，默认为MP4格式
+        :param OutputType: 视频类型，取值0。目前仅支持MP4格式，默认为MP4格式
         :type OutputType: int
         :param OutputWidth: 视频宽度，取值[128,1280]。默认值720
         :type OutputWidth: int
@@ -353,6 +411,13 @@ Url、Image必须提供一个，如果都提供，只使用 Url。图片存储
         self.OutputType = params.get("OutputType")
         self.OutputWidth = params.get("OutputWidth")
         self.OutputHeight = params.get("OutputHeight")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class MorphFaceResponse(AbstractModel):
@@ -395,6 +460,13 @@ class QueryFaceMorphJobRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.JobId = params.get("JobId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class QueryFaceMorphJobResponse(AbstractModel):
@@ -463,6 +535,13 @@ class SwapGenderPicRequest(AbstractModel):
         self.Image = params.get("Image")
         self.Url = params.get("Url")
         self.RspImgType = params.get("RspImgType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SwapGenderPicResponse(AbstractModel):
