@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -94,6 +96,13 @@ class CallBackCdr(AbstractModel):
         self.CallType = params.get("CallType")
         self.BizId = params.get("BizId")
         self.OrderId = params.get("OrderId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CallBackPhoneCode(AbstractModel):
@@ -115,6 +124,13 @@ class CallBackPhoneCode(AbstractModel):
     def _deserialize(self, params):
         self.Nation = params.get("Nation")
         self.Phone = params.get("Phone")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateCallBackRequest(AbstractModel):
@@ -191,6 +207,13 @@ class CreateCallBackRequest(AbstractModel):
             self.PreCallerHandle = RreCallerHandle()
             self.PreCallerHandle._deserialize(params.get("PreCallerHandle"))
         self.OrderId = params.get("OrderId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateCallBackResponse(AbstractModel):
@@ -257,6 +280,13 @@ class DelVirtualNumRequest(AbstractModel):
         self.BizAppId = params.get("BizAppId")
         self.BindId = params.get("BindId")
         self.BizId = params.get("BizId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DelVirtualNumResponse(AbstractModel):
@@ -318,6 +348,13 @@ class DeleteCallBackRequest(AbstractModel):
         self.BizAppId = params.get("BizAppId")
         self.CallId = params.get("CallId")
         self.CancelFlag = params.get("CancelFlag")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteCallBackResponse(AbstractModel):
@@ -382,6 +419,13 @@ class DescribeCallBackCdrRequest(AbstractModel):
         self.Src = params.get("Src")
         self.StartTimeStamp = params.get("StartTimeStamp")
         self.EndTimeStamp = params.get("EndTimeStamp")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeCallBackCdrResponse(AbstractModel):
@@ -457,6 +501,13 @@ class DescribeCallBackStatusRequest(AbstractModel):
         self.Src = params.get("Src")
         self.Dst = params.get("Dst")
         self.CallStatus = params.get("CallStatus")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeCallBackStatusResponse(AbstractModel):
@@ -519,6 +570,13 @@ class DescribeCallerDisplayListRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.BizAppId = params.get("BizAppId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeCallerDisplayListResponse(AbstractModel):
@@ -593,6 +651,13 @@ class Get400CdrRequest(AbstractModel):
         self.Src = params.get("Src")
         self.StartTimeStamp = params.get("StartTimeStamp")
         self.EndTimeStamp = params.get("EndTimeStamp")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Get400CdrResponse(AbstractModel):
@@ -715,6 +780,13 @@ class GetVirtualNumRequest(AbstractModel):
         self.StatusUrl = params.get("StatusUrl")
         self.HangupUrl = params.get("HangupUrl")
         self.RecordUrl = params.get("RecordUrl")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GetVirtualNumResponse(AbstractModel):
@@ -777,6 +849,13 @@ class KeyList(AbstractModel):
     def _deserialize(self, params):
         self.Key = params.get("Key")
         self.Operate = params.get("Operate")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RreCallerHandle(AbstractModel):
@@ -819,6 +898,13 @@ class RreCallerHandle(AbstractModel):
         self.RepeatTimes = params.get("RepeatTimes")
         self.KeyPressUrl = params.get("KeyPressUrl")
         self.PromptGender = params.get("PromptGender")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class VirturalNumCdr(AbstractModel):
@@ -887,4 +973,11 @@ class VirturalNumCdr(AbstractModel):
         self.CallEndStatus = params.get("CallEndStatus")
         self.SrcDuration = params.get("SrcDuration")
         self.DstDuration = params.get("DstDuration")
-        self.RecordUrl = params.get("RecordUrl")
\ No newline at end of file
+        self.RecordUrl = params.get("RecordUrl")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
\ No newline at end of file
