@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -45,7 +47,7 @@ class AgentAuditedClient(AbstractModel):
         :type ThisMonthAmt: int
         :param HasOverdueBill: 是否欠费,0：不欠费；1：欠费
         :type HasOverdueBill: int
-        :param ClientType: 客户类型：可以为new(新拓)/assign(指定)/old(存量)/direct(直销)/direct_newopp(直销(新商机))/空
+        :param ClientType: 客户类型：可以为new(新拓)/assign(指定)/old(存量已关联)/old_newchecking(存量-新关联考核中)/old_newnotpass(存量-新关联未达标)/direct(直销)/direct_newopp(直销(新商机))/空
         :type ClientType: str
         :param ProjectType: 项目类型：可以为self(自拓项目)/platform(合作项目)/repeat(复算项目  )/空
         :type ProjectType: str
@@ -94,6 +96,13 @@ class AgentAuditedClient(AbstractModel):
         self.SalesUin = params.get("SalesUin")
         self.SalesName = params.get("SalesName")
         self.Mail = params.get("Mail")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AgentBillElem(AbstractModel):
@@ -162,6 +171,13 @@ class AgentBillElem(AbstractModel):
         self.ClientType = params.get("ClientType")
         self.ProjectType = params.get("ProjectType")
         self.ActivityId = params.get("ActivityId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AgentClientElem(AbstractModel):
@@ -185,7 +201,7 @@ class AgentClientElem(AbstractModel):
         :type Phone: str
         :param HasOverdueBill: 0表示不欠费，1表示欠费
         :type HasOverdueBill: int
-        :param Status: 1:待代理商审核;2:待腾讯云审核
+        :param Status: 1:待代理商审核;2:待腾讯云审核4:待腾讯云渠道审批
         :type Status: int
         :param SalesUin: 业务员ID
 注意：此字段可能返回 null，表示取不到有效值。
@@ -193,6 +209,9 @@ class AgentClientElem(AbstractModel):
         :param SalesName: 业务员姓名
 注意：此字段可能返回 null，表示取不到有效值。
         :type SalesName: str
+        :param ClientName: 客户名称，此字段和控制台返回一致。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ClientName: str
         """
         self.Uin = None
         self.ClientUin = None
@@ -204,6 +223,7 @@ class AgentClientElem(AbstractModel):
         self.Status = None
         self.SalesUin = None
         self.SalesName = None
+        self.ClientName = None
 
 
     def _deserialize(self, params):
@@ -217,6 +237,14 @@ class AgentClientElem(AbstractModel):
         self.Status = params.get("Status")
         self.SalesUin = params.get("SalesUin")
         self.SalesName = params.get("SalesName")
+        self.ClientName = params.get("ClientName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AgentDealElem(AbstractModel):
@@ -300,6 +328,12 @@ class AgentDealElem(AbstractModel):
         :param ProductInfo: 产品详情
 注意：此字段可能返回 null，表示取不到有效值。
         :type ProductInfo: list of ProductInfoElem
+        :param PaymentMethod: 付款方式
+注意：此字段可能返回 null，表示取不到有效值。
+        :type PaymentMethod: str
+        :param UpdateTime: 订单更新时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :type UpdateTime: str
         """
         self.DealId = None
         self.DealName = None
@@ -327,6 +361,8 @@ class AgentDealElem(AbstractModel):
         self.ActivityId = None
         self.OverdueTime = None
         self.ProductInfo = None
+        self.PaymentMethod = None
+        self.UpdateTime = None
 
 
     def _deserialize(self, params):
@@ -363,6 +399,15 @@ class AgentDealElem(AbstractModel):
                 obj = ProductInfoElem()
                 obj._deserialize(item)
                 self.ProductInfo.append(obj)
+        self.PaymentMethod = params.get("PaymentMethod")
+        self.UpdateTime = params.get("UpdateTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AgentDealNewElem(AbstractModel):
@@ -446,6 +491,12 @@ class AgentDealNewElem(AbstractModel):
         :param ProductInfo: 产品详情
 注意：此字段可能返回 null，表示取不到有效值。
         :type ProductInfo: list of ProductInfoElem
+        :param PaymentMethod: 付款方式
+注意：此字段可能返回 null，表示取不到有效值。
+        :type PaymentMethod: str
+        :param UpdateTime: 订单更新时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :type UpdateTime: str
         """
         self.DealId = None
         self.DealName = None
@@ -473,6 +524,8 @@ class AgentDealNewElem(AbstractModel):
         self.ActivityId = None
         self.OverdueTime = None
         self.ProductInfo = None
+        self.PaymentMethod = None
+        self.UpdateTime = None
 
 
     def _deserialize(self, params):
@@ -509,6 +562,15 @@ class AgentDealNewElem(AbstractModel):
                 obj = ProductInfoElem()
                 obj._deserialize(item)
                 self.ProductInfo.append(obj)
+        self.PaymentMethod = params.get("PaymentMethod")
+        self.UpdateTime = params.get("UpdateTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AgentPayDealsRequest(AbstractModel):
@@ -534,6 +596,13 @@ class AgentPayDealsRequest(AbstractModel):
         self.OwnerUin = params.get("OwnerUin")
         self.AgentPay = params.get("AgentPay")
         self.DealNames = params.get("DealNames")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AgentPayDealsResponse(AbstractModel):
@@ -580,6 +649,13 @@ class AgentSalesmanElem(AbstractModel):
         self.SalesUin = params.get("SalesUin")
         self.SalesName = params.get("SalesName")
         self.CreateTime = params.get("CreateTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AgentTransferMoneyRequest(AbstractModel):
@@ -601,6 +677,13 @@ class AgentTransferMoneyRequest(AbstractModel):
     def _deserialize(self, params):
         self.ClientUin = params.get("ClientUin")
         self.Amount = params.get("Amount")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AgentTransferMoneyResponse(AbstractModel):
@@ -643,6 +726,13 @@ class AuditApplyClientRequest(AbstractModel):
         self.ClientUin = params.get("ClientUin")
         self.AuditResult = params.get("AuditResult")
         self.Note = params.get("Note")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AuditApplyClientResponse(AbstractModel):
@@ -679,7 +769,7 @@ class AuditApplyClientResponse(AbstractModel):
 
 
 class ClientBaseElem(AbstractModel):
-    """代客基础信息，for国际站查代客API
+    """代客基础信息
 
     """
 
@@ -709,6 +799,13 @@ class ClientBaseElem(AbstractModel):
         self.ClientRelateType = params.get("ClientRelateType")
         self.AgentCooperationMode = params.get("AgentCooperationMode")
         self.AgentCountry = params.get("AgentCountry")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreatePayRelationForClientRequest(AbstractModel):
@@ -726,6 +823,13 @@ class CreatePayRelationForClientRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.ClientUin = params.get("ClientUin")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreatePayRelationForClientResponse(AbstractModel):
@@ -752,14 +856,25 @@ class DealGoodsPriceElem(AbstractModel):
 
     def __init__(self):
         """
-        :param RealTotalCost: 实付金额
+        :param RealTotalCost: 实付金额（单位：分）
         :type RealTotalCost: int
+        :param OriginalTotalCost: 订单实际金额（不含折扣，单位：分）
+        :type OriginalTotalCost: int
         """
         self.RealTotalCost = None
+        self.OriginalTotalCost = None
 
 
     def _deserialize(self, params):
         self.RealTotalCost = params.get("RealTotalCost")
+        self.OriginalTotalCost = params.get("OriginalTotalCost")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DealGoodsPriceNewElem(AbstractModel):
@@ -769,14 +884,25 @@ class DealGoodsPriceNewElem(AbstractModel):
 
     def __init__(self):
         """
-        :param RealTotalCost: 实付金额
+        :param RealTotalCost: 实付金额（单位：分）
         :type RealTotalCost: int
+        :param OriginalTotalCost: 原始金额（不含折扣，单位：分）
+        :type OriginalTotalCost: int
         """
         self.RealTotalCost = None
+        self.OriginalTotalCost = None
 
 
     def _deserialize(self, params):
         self.RealTotalCost = params.get("RealTotalCost")
+        self.OriginalTotalCost = params.get("OriginalTotalCost")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeAgentAuditedClientsRequest(AbstractModel):
@@ -804,7 +930,7 @@ class DescribeAgentAuditedClientsRequest(AbstractModel):
         :type Offset: int
         :param Limit: 限制数目
         :type Limit: int
-        :param ClientType: 客户类型：可以为new(新拓)/assign(指定)/old(存量)/空
+        :param ClientType: 客户类型：可以为new(新拓)/assign(指定)/old(存量已关联)/old_newchecking(存量-新关联考核中)/old_newnotpass(存量-新关联未达标)/direct(直销)/direct_newopp(直销(新商机))/空
         :type ClientType: str
         :param ProjectType: 项目类型：可以为self(自拓项目)/platform(合作项目)/repeat(复算项目  )/空
         :type ProjectType: str
@@ -842,6 +968,13 @@ class DescribeAgentAuditedClientsRequest(AbstractModel):
         self.ProjectType = params.get("ProjectType")
         self.SalesUin = params.get("SalesUin")
         self.SalesName = params.get("SalesName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeAgentAuditedClientsResponse(AbstractModel):
@@ -913,6 +1046,13 @@ class DescribeAgentBillsRequest(AbstractModel):
         self.ClientRemark = params.get("ClientRemark")
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeAgentBillsResponse(AbstractModel):
@@ -960,6 +1100,13 @@ class DescribeAgentClientGradeRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.ClientUin = params.get("ClientUin")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeAgentClientGradeResponse(AbstractModel):
@@ -1038,6 +1185,13 @@ class DescribeAgentClientsRequest(AbstractModel):
         self.Limit = params.get("Limit")
         self.SalesUin = params.get("SalesUin")
         self.SalesName = params.get("SalesName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeAgentClientsResponse(AbstractModel):
@@ -1117,6 +1271,13 @@ class DescribeAgentDealsByCacheRequest(AbstractModel):
         self.OwnerUins = params.get("OwnerUins")
         self.DealNames = params.get("DealNames")
         self.PayerMode = params.get("PayerMode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeAgentDealsByCacheResponse(AbstractModel):
@@ -1196,6 +1357,13 @@ class DescribeAgentDealsCacheRequest(AbstractModel):
         self.OwnerUins = params.get("OwnerUins")
         self.DealNames = params.get("DealNames")
         self.PayerMode = params.get("PayerMode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeAgentDealsCacheResponse(AbstractModel):
@@ -1271,6 +1439,13 @@ class DescribeAgentPayDealsRequest(AbstractModel):
         self.Status = params.get("Status")
         self.OwnerUins = params.get("OwnerUins")
         self.DealNames = params.get("DealNames")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeAgentPayDealsResponse(AbstractModel):
@@ -1346,6 +1521,13 @@ class DescribeAgentPayDealsV2Request(AbstractModel):
         self.Status = params.get("Status")
         self.OwnerUins = params.get("OwnerUins")
         self.DealNames = params.get("DealNames")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeAgentPayDealsV2Response(AbstractModel):
@@ -1421,6 +1603,13 @@ class DescribeAgentSelfPayDealsRequest(AbstractModel):
         self.Order = params.get("Order")
         self.Status = params.get("Status")
         self.DealNames = params.get("DealNames")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeAgentSelfPayDealsResponse(AbstractModel):
@@ -1496,6 +1685,13 @@ class DescribeAgentSelfPayDealsV2Request(AbstractModel):
         self.Order = params.get("Order")
         self.Status = params.get("Status")
         self.DealNames = params.get("DealNames")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeAgentSelfPayDealsV2Response(AbstractModel):
@@ -1528,6 +1724,55 @@ class DescribeAgentSelfPayDealsV2Response(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeClientBalanceNewRequest(AbstractModel):
+    """DescribeClientBalanceNew请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param ClientUin: 客户(代客)账号ID
+        :type ClientUin: str
+        """
+        self.ClientUin = None
+
+
+    def _deserialize(self, params):
+        self.ClientUin = params.get("ClientUin")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeClientBalanceNewResponse(AbstractModel):
+    """DescribeClientBalanceNew返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Balance: 账户可用余额，单位分 （可用余额 = 现金余额 + 赠送金余额 - 欠费金额 - 冻结金额）
+        :type Balance: int
+        :param Cash: 账户现金余额，单位分
+        :type Cash: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Balance = None
+        self.Cash = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.Balance = params.get("Balance")
+        self.Cash = params.get("Cash")
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeClientBalanceRequest(AbstractModel):
     """DescribeClientBalance请求参数结构体
 
@@ -1543,6 +1788,13 @@ class DescribeClientBalanceRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.ClientUin = params.get("ClientUin")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeClientBalanceResponse(AbstractModel):
@@ -1585,6 +1837,13 @@ class DescribeClientBaseInfoRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.ClientUin = params.get("ClientUin")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeClientBaseInfoResponse(AbstractModel):
@@ -1640,6 +1899,13 @@ class DescribeRebateInfosRequest(AbstractModel):
         self.RebateMonth = params.get("RebateMonth")
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeRebateInfosResponse(AbstractModel):
@@ -1703,6 +1969,13 @@ class DescribeSalesmansRequest(AbstractModel):
         self.SalesName = params.get("SalesName")
         self.SalesUin = params.get("SalesUin")
         self.OrderDirection = params.get("OrderDirection")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeSalesmansResponse(AbstractModel):
@@ -1774,6 +2047,13 @@ class DescribeUnbindClientListRequest(AbstractModel):
         self.ApplyTimeStart = params.get("ApplyTimeStart")
         self.ApplyTimeEnd = params.get("ApplyTimeEnd")
         self.OrderDirection = params.get("OrderDirection")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeUnbindClientListResponse(AbstractModel):
@@ -1825,6 +2105,13 @@ class ModifyClientRemarkRequest(AbstractModel):
     def _deserialize(self, params):
         self.ClientRemark = params.get("ClientRemark")
         self.ClientUin = params.get("ClientUin")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifyClientRemarkResponse(AbstractModel):
@@ -1863,6 +2150,13 @@ class ProductInfoElem(AbstractModel):
     def _deserialize(self, params):
         self.Name = params.get("Name")
         self.Value = params.get("Value")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RebateInfoElem(AbstractModel):
@@ -1900,6 +2194,13 @@ class RebateInfoElem(AbstractModel):
         self.MonthSales = params.get("MonthSales")
         self.QuarterSales = params.get("QuarterSales")
         self.ExceptionFlag = params.get("ExceptionFlag")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RemovePayRelationForClientRequest(AbstractModel):
@@ -1917,6 +2218,13 @@ class RemovePayRelationForClientRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.ClientUin = params.get("ClientUin")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RemovePayRelationForClientResponse(AbstractModel):
@@ -1968,4 +2276,11 @@ class UnbindClientElem(AbstractModel):
         self.Name = params.get("Name")
         self.Status = params.get("Status")
         self.ApplyTime = params.get("ApplyTime")
-        self.ActionTime = params.get("ActionTime")
\ No newline at end of file
+        self.ActionTime = params.get("ActionTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
\ No newline at end of file
