@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -82,7 +82,7 @@ class InitOralProcessRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -105,13 +105,6 @@ class InitOralProcessResponse(AbstractModel):
     def _deserialize(self, params):
         self.SessionId = params.get("SessionId")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class Keyword(AbstractModel):
@@ -150,7 +143,7 @@ class Keyword(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -211,7 +204,7 @@ class KeywordEvaluateRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -243,13 +236,6 @@ class KeywordEvaluateResponse(AbstractModel):
                 self.KeywordScores.append(obj)
         self.SessionId = params.get("SessionId")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class KeywordScore(AbstractModel):
@@ -298,7 +284,7 @@ class KeywordScore(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -317,7 +303,7 @@ class PhoneInfo(AbstractModel):
         :type PronAccuracy: float
         :param DetectedStress: 当前音节是否检测为重音
         :type DetectedStress: bool
-        :param Phone: 当前音节
+        :param Phone: 当前音节，当前评测识别的音素
         :type Phone: str
         :param Stress: 当前音节是否应为重音
         :type Stress: bool
@@ -325,6 +311,8 @@ class PhoneInfo(AbstractModel):
         :type ReferencePhone: str
         :param MatchTag: 当前词与输入语句的匹配情况，0：匹配单词、1：新增单词、2：缺少单词、3：错读的词、4：未录入单词。
         :type MatchTag: int
+        :param ReferenceLetter: 参考字符，在单词诊断模式下，代表音素对应的原始文本
+        :type ReferenceLetter: str
         """
         self.MemBeginTime = None
         self.MemEndTime = None
@@ -334,6 +322,7 @@ class PhoneInfo(AbstractModel):
         self.Stress = None
         self.ReferencePhone = None
         self.MatchTag = None
+        self.ReferenceLetter = None
 
 
     def _deserialize(self, params):
@@ -345,12 +334,13 @@ class PhoneInfo(AbstractModel):
         self.Stress = params.get("Stress")
         self.ReferencePhone = params.get("ReferencePhone")
         self.MatchTag = params.get("MatchTag")
+        self.ReferenceLetter = params.get("ReferenceLetter")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -399,7 +389,7 @@ class SentenceInfo(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -414,7 +404,7 @@ class TransmitOralProcessRequest(AbstractModel):
         :type SeqId: int
         :param IsEnd: 是否传输完毕标志，若为0表示未完毕，若为1则传输完毕开始评估，非流式模式下无意义。
         :type IsEnd: int
-        :param VoiceFileType: 语音文件类型 	1:raw, 2:wav, 3:mp3(三种格式目前仅支持16k采样率16bit编码单声道，如有不一致可能导致评估不准确或失败)。
+        :param VoiceFileType: 语音文件类型 	1: raw, 2: wav, 3: mp3, 4: speex (语言文件格式目前仅支持 16k 采样率 16bit 编码单声道，如有不一致可能导致评估不准确或失败)。
         :type VoiceFileType: int
         :param VoiceEncodeType: 语音编码类型	1:pcm。
         :type VoiceEncodeType: int
@@ -455,7 +445,7 @@ class TransmitOralProcessRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -520,13 +510,6 @@ class TransmitOralProcessResponse(AbstractModel):
         self.Status = params.get("Status")
         self.SuggestedScore = params.get("SuggestedScore")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class TransmitOralProcessWithInitRequest(AbstractModel):
@@ -586,7 +569,7 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
 0：不存储
 1：存储到公共对象存储，不会产生费用，存储时间为一个月。输出结果为该会话最后一个分片TransmitOralProcess 返回结果 AudioUrl 字段；
 2：永久存储音频，需要提工单申请，会产生一定的存储费用；
-3：自定义存储，将音频存储到自定义的腾讯云[对象存储](https://cloud.tencent.com/product/cos)中，需要提工单登记存储信息。关于自定义存储cos基础设置的方式，请查看下文自定义存储cos基础设置流程。
+3：自定义存储，将音频存储到自定义的腾讯云[对象存储](https://cloud.tencent.com/product/cos)中。
 注：对可用性要求较高的用户建议自行存储至腾讯云COS。
         :type StorageMode: int
         :param SentenceInfoEnabled: 输出断句中间结果标识
@@ -653,7 +636,7 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -718,13 +701,6 @@ class TransmitOralProcessWithInitResponse(AbstractModel):
         self.Status = params.get("Status")
         self.SuggestedScore = params.get("SuggestedScore")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class WordRsp(AbstractModel):
@@ -780,5 +756,5 @@ class WordRsp(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
\ No newline at end of file
