@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -35,6 +37,13 @@ class AgePortrait(AbstractModel):
     def _deserialize(self, params):
         self.AgeRange = params.get("AgeRange")
         self.Percent = params.get("Percent")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AgePortraitInfo(AbstractModel):
@@ -57,6 +66,13 @@ class AgePortraitInfo(AbstractModel):
                 obj = AgePortrait()
                 obj._deserialize(item)
                 self.PortraitSet.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class BrandReportArticle(AbstractModel):
@@ -106,6 +122,13 @@ class BrandReportArticle(AbstractModel):
         self.Level = params.get("Level")
         self.Abstract = params.get("Abstract")
         self.ArticleId = params.get("ArticleId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Comment(AbstractModel):
@@ -131,6 +154,13 @@ class Comment(AbstractModel):
         self.Date = params.get("Date")
         self.NegCommentCount = params.get("NegCommentCount")
         self.PosCommentCount = params.get("PosCommentCount")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CommentInfo(AbstractModel):
@@ -152,6 +182,13 @@ class CommentInfo(AbstractModel):
     def _deserialize(self, params):
         self.Comment = params.get("Comment")
         self.Date = params.get("Date")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DateCount(AbstractModel):
@@ -173,6 +210,13 @@ class DateCount(AbstractModel):
     def _deserialize(self, params):
         self.Date = params.get("Date")
         self.Count = params.get("Count")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeBrandCommentCountRequest(AbstractModel):
@@ -198,6 +242,13 @@ class DescribeBrandCommentCountRequest(AbstractModel):
         self.BrandId = params.get("BrandId")
         self.StartDate = params.get("StartDate")
         self.EndDate = params.get("EndDate")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeBrandCommentCountResponse(AbstractModel):
@@ -249,6 +300,13 @@ class DescribeBrandExposureRequest(AbstractModel):
         self.BrandId = params.get("BrandId")
         self.StartDate = params.get("StartDate")
         self.EndDate = params.get("EndDate")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeBrandExposureResponse(AbstractModel):
@@ -304,6 +362,13 @@ class DescribeBrandMediaReportRequest(AbstractModel):
         self.BrandId = params.get("BrandId")
         self.StartDate = params.get("StartDate")
         self.EndDate = params.get("EndDate")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeBrandMediaReportResponse(AbstractModel):
@@ -367,6 +432,13 @@ class DescribeBrandNegCommentsRequest(AbstractModel):
         self.EndDate = params.get("EndDate")
         self.Limit = params.get("Limit")
         self.Offset = params.get("Offset")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeBrandNegCommentsResponse(AbstractModel):
@@ -430,6 +502,13 @@ class DescribeBrandPosCommentsRequest(AbstractModel):
         self.EndDate = params.get("EndDate")
         self.Limit = params.get("Limit")
         self.Offset = params.get("Offset")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeBrandPosCommentsResponse(AbstractModel):
@@ -497,6 +576,13 @@ class DescribeBrandSocialOpinionRequest(AbstractModel):
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
         self.ShowList = params.get("ShowList")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeBrandSocialOpinionResponse(AbstractModel):
@@ -560,6 +646,13 @@ class DescribeBrandSocialReportRequest(AbstractModel):
         self.BrandId = params.get("BrandId")
         self.StartDate = params.get("StartDate")
         self.EndDate = params.get("EndDate")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeBrandSocialReportResponse(AbstractModel):
@@ -627,6 +720,13 @@ class DescribeIndustryNewsRequest(AbstractModel):
         self.ShowList = params.get("ShowList")
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeIndustryNewsResponse(AbstractModel):
@@ -691,6 +791,13 @@ class DescribeUserPortraitRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.BrandId = params.get("BrandId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeUserPortraitResponse(AbstractModel):
@@ -759,6 +866,13 @@ class GenderPortrait(AbstractModel):
     def _deserialize(self, params):
         self.Gender = params.get("Gender")
         self.Percent = params.get("Percent")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class GenderPortraitInfo(AbstractModel):
@@ -781,6 +895,13 @@ class GenderPortraitInfo(AbstractModel):
                 obj = GenderPortrait()
                 obj._deserialize(item)
                 self.PortraitSet.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class IndustryNews(AbstractModel):
@@ -830,6 +951,13 @@ class IndustryNews(AbstractModel):
         self.Hot = params.get("Hot")
         self.Flag = params.get("Flag")
         self.Abstract = params.get("Abstract")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class MoviePortrait(AbstractModel):
@@ -851,6 +979,13 @@ class MoviePortrait(AbstractModel):
     def _deserialize(self, params):
         self.Name = params.get("Name")
         self.Percent = params.get("Percent")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class MoviePortraitInfo(AbstractModel):
@@ -873,6 +1008,13 @@ class MoviePortraitInfo(AbstractModel):
                 obj = MoviePortrait()
                 obj._deserialize(item)
                 self.PortraitSet.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ProvincePortrait(AbstractModel):
@@ -894,6 +1036,13 @@ class ProvincePortrait(AbstractModel):
     def _deserialize(self, params):
         self.Province = params.get("Province")
         self.Percent = params.get("Percent")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ProvincePortraitInfo(AbstractModel):
@@ -916,6 +1065,13 @@ class ProvincePortraitInfo(AbstractModel):
                 obj = ProvincePortrait()
                 obj._deserialize(item)
                 self.PortraitSet.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class StarPortrait(AbstractModel):
@@ -937,6 +1093,13 @@ class StarPortrait(AbstractModel):
     def _deserialize(self, params):
         self.Name = params.get("Name")
         self.Percent = params.get("Percent")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class StarPortraitInfo(AbstractModel):
@@ -958,4 +1121,11 @@ class StarPortraitInfo(AbstractModel):
             for item in params.get("PortraitSet"):
                 obj = StarPortrait()
                 obj._deserialize(item)
-                self.PortraitSet.append(obj)
\ No newline at end of file
+                self.PortraitSet.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
\ No newline at end of file
