@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -36,6 +38,13 @@ class AbnormalEvent(AbstractModel):
     def _deserialize(self, params):
         self.AbnormalEventId = params.get("AbnormalEventId")
         self.PeerId = params.get("PeerId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class AbnormalExperience(AbstractModel):
@@ -74,6 +83,13 @@ class AbnormalExperience(AbstractModel):
                 obj._deserialize(item)
                 self.AbnormalEventList.append(obj)
         self.EventTime = params.get("EventTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreatePictureRequest(AbstractModel):
@@ -115,6 +131,13 @@ class CreatePictureRequest(AbstractModel):
         self.Width = params.get("Width")
         self.XPosition = params.get("XPosition")
         self.YPosition = params.get("YPosition")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreatePictureResponse(AbstractModel):
@@ -189,6 +212,13 @@ class CreateTroubleInfoRequest(AbstractModel):
         self.TroubleType = params.get("TroubleType")
         self.TroubleTime = params.get("TroubleTime")
         self.TroubleMsg = params.get("TroubleMsg")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateTroubleInfoResponse(AbstractModel):
@@ -227,6 +257,13 @@ class DeletePictureRequest(AbstractModel):
     def _deserialize(self, params):
         self.PictureId = params.get("PictureId")
         self.SdkAppId = params.get("SdkAppId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeletePictureResponse(AbstractModel):
@@ -273,6 +310,13 @@ class DescribeAbnormalEventRequest(AbstractModel):
         self.StartTime = params.get("StartTime")
         self.EndTime = params.get("EndTime")
         self.RoomId = params.get("RoomId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeAbnormalEventResponse(AbstractModel):
@@ -361,6 +405,13 @@ bigvHeight：上/下行分辨率高
         self.DataType = params.get("DataType")
         self.PageNumber = params.get("PageNumber")
         self.PageSize = params.get("PageSize")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeCallDetailResponse(AbstractModel):
@@ -435,6 +486,13 @@ class DescribeDetailEventRequest(AbstractModel):
         self.EndTime = params.get("EndTime")
         self.UserId = params.get("UserId")
         self.RoomId = params.get("RoomId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeDetailEventResponse(AbstractModel):
@@ -486,6 +544,13 @@ class DescribeHistoryScaleRequest(AbstractModel):
         self.SdkAppId = params.get("SdkAppId")
         self.StartTime = params.get("StartTime")
         self.EndTime = params.get("EndTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeHistoryScaleResponse(AbstractModel):
@@ -546,6 +611,13 @@ class DescribePictureRequest(AbstractModel):
         self.PictureId = params.get("PictureId")
         self.PageSize = params.get("PageSize")
         self.PageNo = params.get("PageNo")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribePictureResponse(AbstractModel):
@@ -607,6 +679,13 @@ recvLossRateRaw：下行丢包率
         self.EndTime = params.get("EndTime")
         self.SdkAppId = params.get("SdkAppId")
         self.DataType = params.get("DataType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeRealtimeNetworkResponse(AbstractModel):
@@ -666,6 +745,13 @@ audioBlockPercent：音频卡顿率
         self.EndTime = params.get("EndTime")
         self.SdkAppId = params.get("SdkAppId")
         self.DataType = params.get("DataType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeRealtimeQualityResponse(AbstractModel):
@@ -723,6 +809,13 @@ RoomNum：房间数
         self.EndTime = params.get("EndTime")
         self.SdkAppId = params.get("SdkAppId")
         self.DataType = params.get("DataType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeRealtimeScaleResponse(AbstractModel):
@@ -775,6 +868,13 @@ class DescribeRecordStatisticRequest(AbstractModel):
         self.StartTime = params.get("StartTime")
         self.EndTime = params.get("EndTime")
         self.SdkAppId = params.get("SdkAppId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeRecordStatisticResponse(AbstractModel):
@@ -838,6 +938,13 @@ class DescribeRoomInformationRequest(AbstractModel):
         self.RoomId = params.get("RoomId")
         self.PageNumber = params.get("PageNumber")
         self.PageSize = params.get("PageSize")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeRoomInformationResponse(AbstractModel):
@@ -894,6 +1001,13 @@ class DescribeTrtcInteractiveTimeRequest(AbstractModel):
         self.StartTime = params.get("StartTime")
         self.EndTime = params.get("EndTime")
         self.SdkAppId = params.get("SdkAppId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeTrtcInteractiveTimeResponse(AbstractModel):
@@ -946,6 +1060,13 @@ class DescribeTrtcMcuTranscodeTimeRequest(AbstractModel):
         self.StartTime = params.get("StartTime")
         self.EndTime = params.get("EndTime")
         self.SdkAppId = params.get("SdkAppId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeTrtcMcuTranscodeTimeResponse(AbstractModel):
@@ -1013,6 +1134,13 @@ class DescribeUserInformationRequest(AbstractModel):
         self.UserIds = params.get("UserIds")
         self.PageNumber = params.get("PageNumber")
         self.PageSize = params.get("PageSize")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeUserInformationResponse(AbstractModel):
@@ -1065,6 +1193,13 @@ class DismissRoomByStrRoomIdRequest(AbstractModel):
     def _deserialize(self, params):
         self.SdkAppId = params.get("SdkAppId")
         self.RoomId = params.get("RoomId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DismissRoomByStrRoomIdResponse(AbstractModel):
@@ -1103,6 +1238,13 @@ class DismissRoomRequest(AbstractModel):
     def _deserialize(self, params):
         self.SdkAppId = params.get("SdkAppId")
         self.RoomId = params.get("RoomId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DismissRoomResponse(AbstractModel):
@@ -1184,6 +1326,13 @@ class EncodeParams(AbstractModel):
         self.BackgroundColor = params.get("BackgroundColor")
         self.BackgroundImageId = params.get("BackgroundImageId")
         self.AudioCodec = params.get("AudioCodec")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EventList(AbstractModel):
@@ -1210,6 +1359,13 @@ class EventList(AbstractModel):
                 obj._deserialize(item)
                 self.Content.append(obj)
         self.PeerId = params.get("PeerId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EventMessage(AbstractModel):
@@ -1247,6 +1403,13 @@ class EventMessage(AbstractModel):
         self.EventId = params.get("EventId")
         self.ParamOne = params.get("ParamOne")
         self.ParamTwo = params.get("ParamTwo")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class LayoutParams(AbstractModel):
@@ -1274,6 +1437,8 @@ class LayoutParams(AbstractModel):
         :type PlaceHolderMode: int
         :param PureAudioHoldPlaceMode: 悬浮模板、九宫格、屏幕分享模板生效，用于控制纯音频上行是否占用画面布局位置。设置为0是代表后台默认处理方式，悬浮小画面占布局位置，九宫格画面占布局位置、屏幕分享小画面不占布局位置；设置为1时代表纯音频上行占布局位置；设置为2时代表纯音频上行不占布局位置。默认为0。
         :type PureAudioHoldPlaceMode: int
+        :param WaterMarkParams: 水印参数。
+        :type WaterMarkParams: :class:`tencentcloud.trtc.v20190722.models.WaterMarkParams`
         """
         self.Template = None
         self.MainVideoUserId = None
@@ -1284,6 +1449,7 @@ class LayoutParams(AbstractModel):
         self.PresetLayoutConfig = None
         self.PlaceHolderMode = None
         self.PureAudioHoldPlaceMode = None
+        self.WaterMarkParams = None
 
 
     def _deserialize(self, params):
@@ -1303,6 +1469,16 @@ class LayoutParams(AbstractModel):
                 self.PresetLayoutConfig.append(obj)
         self.PlaceHolderMode = params.get("PlaceHolderMode")
         self.PureAudioHoldPlaceMode = params.get("PureAudioHoldPlaceMode")
+        if params.get("WaterMarkParams") is not None:
+            self.WaterMarkParams = WaterMarkParams()
+            self.WaterMarkParams._deserialize(params.get("WaterMarkParams"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifyPictureRequest(AbstractModel):
@@ -1340,6 +1516,13 @@ class ModifyPictureRequest(AbstractModel):
         self.Width = params.get("Width")
         self.XPosition = params.get("XPosition")
         self.YPosition = params.get("YPosition")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifyPictureResponse(AbstractModel):
@@ -1387,6 +1570,13 @@ class OneSdkAppIdTranscodeTimeUsagesInfo(AbstractModel):
                 self.SdkAppIdTranscodeTimeUsages.append(obj)
         self.TotalNum = params.get("TotalNum")
         self.SdkAppId = params.get("SdkAppId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class OneSdkAppIdUsagesInfo(AbstractModel):
@@ -1417,6 +1607,13 @@ class OneSdkAppIdUsagesInfo(AbstractModel):
                 obj._deserialize(item)
                 self.SdkAppIdTrtcTimeUsages.append(obj)
         self.SdkAppId = params.get("SdkAppId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class OutputParams(AbstractModel):
@@ -1446,6 +1643,13 @@ class OutputParams(AbstractModel):
         self.PureAudioStream = params.get("PureAudioStream")
         self.RecordId = params.get("RecordId")
         self.RecordAudioOnly = params.get("RecordAudioOnly")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class PictureInfo(AbstractModel):
@@ -1483,6 +1687,13 @@ class PictureInfo(AbstractModel):
         self.YPosition = params.get("YPosition")
         self.SdkAppId = params.get("SdkAppId")
         self.PictureId = params.get("PictureId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class PresetLayoutConfig(AbstractModel):
@@ -1504,7 +1715,7 @@ class PresetLayoutConfig(AbstractModel):
         :type LocationX: int
         :param LocationY: 该画面在输出时的Y偏移，单位为像素值，LocationY与ImageHeight之和不能超过混流输出的总高度，不填默认为0。
         :type LocationY: int
-        :param ZOrder: 该画面在输出时的层级，单位为像素值，不填默认为0。
+        :param ZOrder: 该画面在输出时的层级，不填默认为0。
         :type ZOrder: int
         :param RenderMode: 该画面在输出时的显示模式：0为裁剪，1为缩放，2为缩放并显示黑底。不填默认为0。
         :type RenderMode: int
@@ -1536,6 +1747,13 @@ class PresetLayoutConfig(AbstractModel):
         self.RenderMode = params.get("RenderMode")
         self.MixInputType = params.get("MixInputType")
         self.PlaceImageId = params.get("PlaceImageId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class PublishCdnParams(AbstractModel):
@@ -1557,6 +1775,13 @@ class PublishCdnParams(AbstractModel):
     def _deserialize(self, params):
         self.BizId = params.get("BizId")
         self.PublishCdnUrls = params.get("PublishCdnUrls")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class QualityData(AbstractModel):
@@ -1592,6 +1817,13 @@ class QualityData(AbstractModel):
         self.UserId = params.get("UserId")
         self.PeerId = params.get("PeerId")
         self.DataType = params.get("DataType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RealtimeData(AbstractModel):
@@ -1619,6 +1851,13 @@ class RealtimeData(AbstractModel):
                 obj._deserialize(item)
                 self.Content.append(obj)
         self.DataType = params.get("DataType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RecordUsage(AbstractModel):
@@ -1652,6 +1891,13 @@ class RecordUsage(AbstractModel):
         self.Class2VideoTime = params.get("Class2VideoTime")
         self.Class3VideoTime = params.get("Class3VideoTime")
         self.AudioTime = params.get("AudioTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RemoveUserByStrRoomIdRequest(AbstractModel):
@@ -1677,6 +1923,13 @@ class RemoveUserByStrRoomIdRequest(AbstractModel):
         self.SdkAppId = params.get("SdkAppId")
         self.RoomId = params.get("RoomId")
         self.UserIds = params.get("UserIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RemoveUserByStrRoomIdResponse(AbstractModel):
@@ -1719,6 +1972,13 @@ class RemoveUserRequest(AbstractModel):
         self.SdkAppId = params.get("SdkAppId")
         self.RoomId = params.get("RoomId")
         self.UserIds = params.get("UserIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RemoveUserResponse(AbstractModel):
@@ -1773,6 +2033,13 @@ class RoomState(AbstractModel):
         self.DestroyTime = params.get("DestroyTime")
         self.IsFinished = params.get("IsFinished")
         self.UserId = params.get("UserId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ScaleInfomation(AbstractModel):
@@ -1805,6 +2072,13 @@ class ScaleInfomation(AbstractModel):
         self.UserNumber = params.get("UserNumber")
         self.UserCount = params.get("UserCount")
         self.RoomNumbers = params.get("RoomNumbers")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SdkAppIdRecordUsage(AbstractModel):
@@ -1831,6 +2105,13 @@ class SdkAppIdRecordUsage(AbstractModel):
                 obj = RecordUsage()
                 obj._deserialize(item)
                 self.Usages.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SdkAppIdTrtcMcuTranscodeTimeUsage(AbstractModel):
@@ -1865,6 +2146,13 @@ class SdkAppIdTrtcMcuTranscodeTimeUsage(AbstractModel):
         self.VideoTimeSd = params.get("VideoTimeSd")
         self.VideoTimeHd = params.get("VideoTimeHd")
         self.VideoTimeFhd = params.get("VideoTimeFhd")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SdkAppIdTrtcUsage(AbstractModel):
@@ -1904,6 +2192,13 @@ class SdkAppIdTrtcUsage(AbstractModel):
         self.VideoTimeSd = params.get("VideoTimeSd")
         self.VideoTimeHd = params.get("VideoTimeHd")
         self.VideoTimeHdp = params.get("VideoTimeHdp")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SmallVideoLayoutParams(AbstractModel):
@@ -1941,6 +2236,13 @@ class SmallVideoLayoutParams(AbstractModel):
         self.ImageHeight = params.get("ImageHeight")
         self.LocationX = params.get("LocationX")
         self.LocationY = params.get("LocationY")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class StartMCUMixTranscodeByStrRoomIdRequest(AbstractModel):
@@ -1986,6 +2288,13 @@ class StartMCUMixTranscodeByStrRoomIdRequest(AbstractModel):
         if params.get("PublishCdnParams") is not None:
             self.PublishCdnParams = PublishCdnParams()
             self.PublishCdnParams._deserialize(params.get("PublishCdnParams"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class StartMCUMixTranscodeByStrRoomIdResponse(AbstractModel):
@@ -2048,6 +2357,13 @@ class StartMCUMixTranscodeRequest(AbstractModel):
         if params.get("PublishCdnParams") is not None:
             self.PublishCdnParams = PublishCdnParams()
             self.PublishCdnParams._deserialize(params.get("PublishCdnParams"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class StartMCUMixTranscodeResponse(AbstractModel):
@@ -2086,6 +2402,13 @@ class StopMCUMixTranscodeByStrRoomIdRequest(AbstractModel):
     def _deserialize(self, params):
         self.SdkAppId = params.get("SdkAppId")
         self.StrRoomId = params.get("StrRoomId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class StopMCUMixTranscodeByStrRoomIdResponse(AbstractModel):
@@ -2124,6 +2447,13 @@ class StopMCUMixTranscodeRequest(AbstractModel):
     def _deserialize(self, params):
         self.SdkAppId = params.get("SdkAppId")
         self.RoomId = params.get("RoomId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class StopMCUMixTranscodeResponse(AbstractModel):
@@ -2162,6 +2492,13 @@ class TimeValue(AbstractModel):
     def _deserialize(self, params):
         self.Time = params.get("Time")
         self.Value = params.get("Value")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class UserInformation(AbstractModel):
@@ -2206,4 +2543,51 @@ class UserInformation(AbstractModel):
         self.DeviceType = params.get("DeviceType")
         self.SdkVersion = params.get("SdkVersion")
         self.ClientIp = params.get("ClientIp")
-        self.Finished = params.get("Finished")
\ No newline at end of file
+        self.Finished = params.get("Finished")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class WaterMarkParams(AbstractModel):
+    """MCU混流水印参数
+
+    """
+
+    def __init__(self):
+        """
+        :param WaterMarkId: 混流-水印图片ID。取值为实时音视频控制台上传的图片ID。
+        :type WaterMarkId: int
+        :param WaterMarkWidth: 混流-水印宽。单位为像素值。
+        :type WaterMarkWidth: int
+        :param WaterMarkHeight: 混流-水印高。单位为像素值。
+        :type WaterMarkHeight: int
+        :param LocationX: 水印在输出时的X偏移。单位为像素值。
+        :type LocationX: int
+        :param LocationY: 水印在输出时的Y偏移。单位为像素值。
+        :type LocationY: int
+        """
+        self.WaterMarkId = None
+        self.WaterMarkWidth = None
+        self.WaterMarkHeight = None
+        self.LocationX = None
+        self.LocationY = None
+
+
+    def _deserialize(self, params):
+        self.WaterMarkId = params.get("WaterMarkId")
+        self.WaterMarkWidth = params.get("WaterMarkWidth")
+        self.WaterMarkHeight = params.get("WaterMarkHeight")
+        self.LocationX = params.get("LocationX")
+        self.LocationY = params.get("LocationY")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
\ No newline at end of file
